/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.AllocationTime;
import nl.cloudfarming.client.isobus.model.Position;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;

/**
 * Node for the {@link AllocationTime} Object
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages("isobus project taskdata node name allocationtime=AllocationTime ({0} - {1})")
public class AllocationStampNode extends AbstractNode {

    private static final String ALLOCATION_TIME_NODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_allocation_time.png";

    public AllocationStampNode(AllocationTime allocationTime) {
        super(Children.create(new AllocationStampChildFactory(allocationTime), true));
        setName(Bundle.isobus_project_taskdata_node_name_allocationtime(allocationTime.getStartTime(), allocationTime.getEndTime()));
        setIconBaseWithExtension(ALLOCATION_TIME_NODE_ICON);
    }

    /**
     * <p>Child factory for {@link AllocationTime} object</p>
     * Possible children are {@link Position}
     *
     * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
     */
    static class AllocationStampChildFactory extends ChildFactory<Position> {

        private final AllocationTime allocationTime;

        public AllocationStampChildFactory(AllocationTime allocationTime) {
            this.allocationTime = allocationTime;
        }

        @Override
        protected boolean createKeys(List<Position> toPopulate) {
            Position position = allocationTime.getPosition();
            if (position != null) {
                toPopulate.add(position);
            }
            return true;
        }

        @Override
        protected Node createNodeForKey(Position position) {
            return new PositionNode(position);
        }
    }
}
