/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.*;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;

/**
 * <p>Child factory for {@link CommentAllocation}</p> <p>Possible children are {@link Comment}, {@link CommentValue}
 * and {@link AllocationTime}</p>
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({
        "isobus project taskdata node name comment=Comment ({0})"
    })
public class CommentAllocationChildFactory extends ChildFactory<Node> {

    private final CommentAllocation commentAllocation;
    private static final String COMMENT_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_comment.png";

    public CommentAllocationChildFactory(CommentAllocation commentAllocation) {
        this.commentAllocation = commentAllocation;
    }

    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        //Comment (CCT)
        Comment comment = (Comment) commentAllocation.getCommentId();
        if (comment != null) {
            String description = Bundle.isobus_project_taskdata_node_name_comment(comment.getDesignator());
            toPopulate.add(new IsobusCommonNode(Children.create(new CommentChildFactory(comment), true), comment, COMMENT_ICON, description));
        }

        //CommentListValue CCL
        CommentListValue commentListValue = (CommentListValue) commentAllocation.getCommentListValueId();
        if (commentListValue != null) {
            toPopulate.add(new CommentListValueNode(commentListValue));
        }

        //AllocationTime (ASP)
        AllocationTime allocationTime = commentAllocation.getAllocationTime();
        if (allocationTime != null) {
            toPopulate.add(new AllocationStampNode(allocationTime));
        }
        return true;
    }

    @Override
    protected Node createNodeForKey(Node key) {
        return key;
    }

    /**
     * <p>Child factory for the {@link Comment} object</p> <p>Possible children
     * are {@link CommentGroup} and {@link CommentListValue}
     *
     * @author Gerben Feenstra
     */
    @NbBundle.Messages({
        "isobus project taskdata node name comment group=Comment group ({0})"
    })
    static class CommentChildFactory extends ChildFactory<Node> {

        private static final String COMMENT_GROUP_ICON = "";
        private final Comment comment;

        public CommentChildFactory(Comment comment) {
            this.comment = comment;
        }

        @Override
        protected boolean createKeys(List<Node> toPopulate) {
            //CommentListValue CCL
            for (CommentListValue commentListValue : comment.getCommentListValues()) {
                toPopulate.add(new CommentListValueNode(commentListValue));
            }
            //CommentGroup CCG
            CommentGroup commentGroup = (CommentGroup) comment.getCommentGroupId();
            if (commentGroup != null) {
                String description = Bundle.isobus_project_taskdata_node_name_comment_group(commentGroup.getDesignator());
                toPopulate.add(new IsobusCommonNode(Children.LEAF, commentGroup, COMMENT_GROUP_ICON, description));
            }
            return true;
        }

        @Override
        protected Node createNodeForKey(Node key) {
            return key;
        }
    }
}
