/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.DataLog;
import nl.cloudfarming.client.isobus.model.DeviceElement;
import nl.cloudfarming.client.isobus.model.ValuePresentation;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;

/**
 * <p>Child factory for the {@link DataLog} object</p>
 * <p>Possible children are {@link ValuePresentation} and {@link DeviceElement}</p>
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
public class DataLogChildFactory extends ChildFactory<Node>{

    private final DataLog dataLog;
    
    public DataLogChildFactory(DataLog dataLog){
        this.dataLog = dataLog;
    }
    
    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        //DeviceElement (DET)
        DeviceElement deviceElement = (DeviceElement) dataLog.getDeviceElementId();
        if(deviceElement != null){
            toPopulate.add(new DeviceElementNode(deviceElement));
        }
        
        //ValuePresentation VPN
        ValuePresentation valuePresentation = (ValuePresentation) dataLog.getValuePresentationId();
        if(valuePresentation != null){
            toPopulate.add(new ValuePresentationNode(valuePresentation));
        }
        return true;
    }

    @Override
    protected Node createNodeForKey(Node key) {
        return key;
    }
    
    
    
}
