/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.DeviceElement;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;

/**
 * Node for the {@link DeviceElement} object
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({"isobus project taskdata node name device element=Device element ({0})"})
public class DeviceElementNode extends AbstractNode {

    private static final String DEVICE_ELEMENT_CHILDNODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_device_element.png";

    public DeviceElementNode(DeviceElement deviceElement) {
        super(Children.create(new DeviceElementChildFactory(deviceElement), true), Lookups.fixed(deviceElement));
        setName(Bundle.isobus_project_taskdata_node_name_device_element(deviceElement.getDesignator()));
        setIconBaseWithExtension(DEVICE_ELEMENT_CHILDNODE_ICON);
    }

    /**
     * <p>Child factory for {@link DeviceObjectReference}</p> <p>Possible
     * children are {@link DeviceElement}</p>
     *
     * @author Gerben Feenstra
     */
    @NbBundle.Messages("isobus project taskdata aggregatenode name device object references=DeviceObject references")
    static class DeviceElementChildFactory extends ChildFactory<Node> {

        private static final String DEVICE_OBJECT_REFERENCE_AGGRGATE_NODE_ICON = "";
        private final DeviceElement deviceElement;

        public DeviceElementChildFactory(DeviceElement deviceElement) {
            this.deviceElement = deviceElement;
        }

        @Override
        protected boolean createKeys(List<Node> toPopulate) {
            if (!deviceElement.getDeviceObjectReferences().isEmpty()) {
                String displayName = Bundle.isobus_project_taskdata_aggregatenode_name_device_object_references();
                Children deviceObjectReferenceChildren = Children.create(new AggregateNodeChildFactory<>(deviceElement.getDeviceObjectReferences()), true);
                toPopulate.add(new IsobusAggregateNode(deviceObjectReferenceChildren, DEVICE_OBJECT_REFERENCE_AGGRGATE_NODE_ICON, displayName));
            }
            return true;
        }

        @Override
        protected Node createNodeForKey(Node key) {
            return key;
        }
    }
}
