/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.Customer;
import nl.cloudfarming.client.isobus.model.IsobusFarm;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;

/**
 * Node for {@link IsobusFarm} object
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({
    "isobus project farm node name=Farm ({0})"
})
public class FarmNode extends AbstractNode {

    private static final String ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_farm.png";

    public FarmNode(IsobusFarm farm) {
        super(Children.create(new FarmChildFactory(farm), true), Lookups.fixed(farm));
        setName(Bundle.isobus_project_farm_node_name(farm.getName()));
        setIconBaseWithExtension(ICON);
    }

    /**
     * Child factory for a {@link IsobusFarm} Farm references a {@link Customer}
     *
     * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
     */
    static class FarmChildFactory extends ChildFactory<Node> {

        private IsobusFarm isobusFarm;

        public FarmChildFactory(IsobusFarm isobusFarm) {
            this.isobusFarm = isobusFarm;
        }

        @Override
        protected boolean createKeys(List<Node> toPopulate) {
            if (isobusFarm.getCustomerIdRef() != null) {
                toPopulate.add(new CustomerNode((Customer) isobusFarm.getCustomerIdRef()));
            }
            return true;

        }

        @Override
        protected Node createNodeForKey(Node key) {
            return key;
        }
    }
}
