/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.tree;

import nl.cloudfarming.client.isobus.tree.TaskDataChildFactory;
import java.awt.Image;
import java.awt.datatransfer.Transferable;
import java.util.Arrays;
import javax.swing.Action;
import nl.cloudfarming.client.isobus.model.IsobusTaskData;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.datatransfer.PasteType;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;

/**
 * Root node for the {@link IsobusTaskData} 
 * @author Gerben Feenstra
 */
public class TaskDataRootNode extends FilterNode {
    
    private static final String ISOBUS_TASKDATA_NODE_ICON = "nl/cloudfarming/client/isobus/type/iso.png";
        
    public TaskDataRootNode(IsobusTaskData isobusObj, Node original)  {
        super(original,Children.create(new TaskDataChildFactory(isobusObj), true), new ProxyLookup(Lookups.fixed(isobusObj),original.getLookup()));
    }

    @Override
    public Image getIcon(int type) {
        return ImageUtilities.loadImage(ISOBUS_TASKDATA_NODE_ICON);
    }

    @Override
    public Image getOpenedIcon(int type) {
        return getIcon(type);
    }
    
    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.isobus.project.explorer");
    }
    
    @Override
    public PasteType getDropType(Transferable t, int action, int index) {
        return null;
    }

    @Override
    public Action[] getActions(boolean context) {
        return super.getActions(context);
    }

}
